@@ -2,7 +2,7 @@
 #
 # (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
 #
-# $Id: lib/Paranoid/BerkeleyDB.pm, 2.00 2016/05/13 19:47:47 acorliss Exp $
+# $Id: lib/Paranoid/BerkeleyDB.pm, 2.01 2016/06/17 11:24:54 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -31,7 +31,7 @@ use Paranoid::BerkeleyDB::Env;
 use Paranoid::BerkeleyDB::Db;
 use Carp;
 
-($VERSION) = ( q$Revision: 2.00 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.01 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 use vars qw(@ISA @_properties @_methods);
 
@@ -183,6 +183,18 @@ sub dbh {
     return $rv;
 }
 
+sub cds_lock {
+
+    # Purpose:  Simple wrapper to get a CDS lock
+    # Returns:  CDS Lock
+    # Usage:    $lock = $dbh->cds_lock;
+
+    my $obj = shift;
+    my $dbh = $obj->dbh;
+
+    return $dbh->cds_lock;
+}
+
 sub TIEHASH {
     my @args = @_;
 
@@ -215,15 +227,12 @@ sub STORE {
     my $key = shift;
     my $val = shift;
     my $dbh = $obj->dbh;
-    my $lock;
     my $rv;
 
     pdebug( 'entering w/(%s)(%s)', PDLEVEL3, $key, $val );
     pIn();
 
-    $lock = $dbh->cds_lock if $dbh->cds_enabled;
     $rv = !$dbh->db_put( $key, $val );
-    $lock->cds_unlock if defined $lock;
 
     pOut();
     pdebug( 'leaving w/rv: %s', PDLEVEL3, $rv );
@@ -252,15 +261,12 @@ sub DELETE {
     my $obj = shift;
     my $key = shift;
     my $dbh = $obj->dbh;
-    my $lock;
     my $rv;
 
     pdebug( 'entering w/(%s)', PDLEVEL3, $key );
     pIn();
 
-    $lock = $dbh->cds_lock if $dbh->cds_enabled;
     $rv = !$dbh->db_del($key);
-    $lock->cds_unlock if defined $lock;
 
     pOut();
     pdebug( 'leaving w/rv: %s', PDLEVEL3, $rv );
@@ -378,7 +384,7 @@ Paranoid::BerkeleyDB -- BerkeleyDB Wrapper
 
 =head1 VERSION
 
-$Id: lib/Paranoid/BerkeleyDB.pm, 2.00 2016/05/13 19:47:47 acorliss Exp $
+$Id: lib/Paranoid/BerkeleyDB.pm, 2.01 2016/06/17 11:24:54 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -388,6 +394,12 @@ $Id: lib/Paranoid/BerkeleyDB.pm, 2.00 2016/05/13 19:47:47 acorliss Exp $
 
   # Normal hash activities...
 
+  # Ensure atomic updates
+  $dref = tied %db;
+  $lock = $dref->cds_lock;
+  $db{$key}++;
+  $lock->cds_unlock;
+
   untie %db;
 
 =head1 DESCRIPTION
@@ -428,11 +440,11 @@ module.  The primary differences are as follows:
 This method is called implicitly when an object is tied.  It supports a few
 differnet invocation styles.  The simplest involves simply providing the
 B<Home> and B<Filename> options.  This will set up a CDS environment using the
-defaults documented in L<Paranoid::BerkeleyDB::Env> and
-L<Paranoid::BerkeleyDB::Db>.
+defaults documented in L<Paranoid::BerkeleyDB::Env(3)> and
+L<Paranoid::BerkeleyDB::Db(3)>.
 
 Alternately, you can provide it with B<Filename> and a
-L<Paranoid::BerkeleyDB::Env> object (or subclassed object) that you
+L<Paranoid::BerkeleyDB::Env(3)> object (or subclassed object) that you
 instantiated yourself:
 
   tie %db, Paranoid::BerkeleyDB, 
@@ -440,8 +452,8 @@ instantiated yourself:
     Filename => 'data.db';
 
 Finally, you can provide it with two hash options to fully control the
-environment and database instantiation of L<Paranoid::BerkeleyDB::Env> and
-L<Paranoid::BerkeleyDB::Db>:
+environment and database instantiation of L<Paranoid::BerkeleyDB::Env(3)> and
+L<Paranoid::BerkeleyDB::Db(3)>:
 
   tie %db, Paranoid::BerkeleyDB, 
     Env      => { %envOpts },
@@ -449,9 +461,17 @@ L<Paranoid::BerkeleyDB::Db>:
 
 =head2 dbh
 
-    $dbh = $db->dbh;
+    $dref = tied %db;
+    $dbh  = $dref->dbh;
 
-This method provides access to the L<BerkeleyDB::Btree> object reference.
+This method provides access to the L<BerkeleyDB::Btree(3)> object reference.
+
+=head2 cds_lock
+
+    $dref = tied %db;
+    $lock = $dref->cds_lock;
+
+This methd provides access to the CDS locks for atomic updates.
 
 =head1 DEPENDENCIES
 
