@@ -2,7 +2,7 @@
 #
 # (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
 #
-# $Id: lib/Paranoid/BerkeleyDB/Env.pm, 2.00 2016/05/13 19:47:47 acorliss Exp $
+# $Id: lib/Paranoid/BerkeleyDB/Env.pm, 2.01 2016/06/17 11:24:54 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -29,7 +29,7 @@ use Paranoid::BerkeleyDB::Core;
 use Class::EHierarchy qw(:all);
 use BerkeleyDB;
 
-($VERSION) = ( q$Revision: 2.00 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.01 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 use vars qw(@ISA @_properties @_methods);
 
@@ -259,7 +259,7 @@ Paranoid::BerkeleyDB::Env -- BerkeleyDB CDS Env Object
 
 =head1 VERSION
 
-$Id: lib/Paranoid/BerkeleyDB/Env.pm, 2.00 2016/05/13 19:47:47 acorliss Exp $
+$Id: lib/Paranoid/BerkeleyDB/Env.pm, 2.01 2016/06/17 11:24:54 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -270,14 +270,12 @@ $Id: lib/Paranoid/BerkeleyDB/Env.pm, 2.00 2016/05/13 19:47:47 acorliss Exp $
 
 =head1 DESCRIPTION
 
-This module provides an OO-based wrapper for the BerkeleyDB::Env class.  Using
-this module in lieu of BerkeleyDB::Env directly provides fork-safe operation
-as well as clean shutdown of any databases using the environment.
+This module provides an OO-based wrapper for the BerkeleyDB::Env class.
 
 While this class places no restrictions on the use of any available
-BerkeleyDB::Env options it does automatically deploy some defaults options
-oriented towards CDS access.  These can be overridden, but if you're focused
-on CDS this will simplify their use.
+L<BerkeleyDB::Env(3)> options it does automatically deploy some defaults 
+options oriented towards CDS access.  These can be overridden, but if you're 
+focused on CDS this will simplify their use.
 
 =head1 SUBROUTINES/METHODS
 
@@ -286,7 +284,7 @@ on CDS this will simplify their use.
   $db = Paranoid::BerkeleyDB::Env->new(-Home => './dbdir');
 
 The only required argument is B<-Home>.  For a complete list of all available
-options please see the document in L<BerkeleyDB>.
+options please see the L<BerkeleyDB(3)> man page.
 
 By default the following settings are applied unless overridden:
 
@@ -300,16 +298,16 @@ By default the following settings are applied unless overridden:
 
   $env = $dbe->env;
 
-This returns a handle to the current BerkeleyDB::Env object.  Calling this in
-a child will cause the class to automatically reopen an object to avoid
-conflicts with the parent process.
+This returns a handle to the current L<BerkeleyDB::Env(3)> object.  Calling 
+this in a child will cause the class to automatically reopen an object to 
+avoid conflicts with the parent process.
 
 =head2 dbs
 
   @dbs = $dbe->dbs;
 
 This method returns a list of objects currently using this environment.
-Typically these will be L<Paranoid::BerkeleyDB::Db> objects.
+Typically these will be L<Paranoid::BerkeleyDB::Db(3)> objects.
 
 =head2 DESTROY
 
